"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.autoscaler = void 0;
var eks = require("@aws-cdk/aws-eks");
var iam = require("@aws-cdk/aws-iam");
var autoscaling = require("@aws-cdk/aws-autoscaling");
var ec2 = require("@aws-cdk/aws-ec2");
var core_1 = require("@aws-cdk/core");
var aws_iam_1 = require("@aws-cdk/aws-iam");
var aws_eks_1 = require("@aws-cdk/aws-eks");
function autoscaler(stack, eksr, props) {
    var _a;
    var workerRole = new iam.Role(stack, "Role-" + eksr.props.baseName + "-Worker", {
        assumedBy: new iam.ServicePrincipal("ec2.amazonaws.com"),
    });
    workerRole.addManagedPolicy(aws_iam_1.ManagedPolicy.fromAwsManagedPolicyName("AdministratorAccess"));
    var onDemandASG = new autoscaling.AutoScalingGroup(stack, "ASG-" + eksr.props.baseName, {
        vpc: eksr.eks.vpc,
        role: workerRole,
        minCapacity: props.minCapacity || 1,
        maxCapacity: 10,
        instanceType: new ec2.InstanceType(props.instanceType || "t3.medium"),
        machineImage: new eks.EksOptimizedImage({
            kubernetesVersion: props.k8nVersion || "1.17",
            nodeType: eks.NodeType.STANDARD,
        }),
        blockDevices: (_a = props.blockDevices) === null || _a === void 0 ? void 0 : _a.map(function (i) {
            return {
                deviceName: i.deviceName,
                volume: autoscaling.BlockDeviceVolume.ebs(i.size)
            };
        }),
        updateType: autoscaling.UpdateType.ROLLING_UPDATE,
    });
    core_1.Tags.of(onDemandASG).add("k8s.io/cluster-autoscaler/" + eksr.props.baseName, "owned", {
        applyToLaunchedInstances: true,
    });
    core_1.Tags.of(onDemandASG).add("k8s.io/cluster-autoscaler/enabled", "owned", {
        applyToLaunchedInstances: true,
    });
    eksr.eks.addAutoScalingGroup(onDemandASG, {});
    var autoscalerNS = props.autoscalerNamespace || "kuber";
    var kuberNS = eksr.eks.addManifest("NS-" + eksr.props.baseName + "-" + autoscalerNS, {
        apiVersion: "v1",
        kind: "Namespace",
        metadata: { name: autoscalerNS },
    });
    var clusterAS = eksr.eks.addServiceAccount("SA-" + eksr.props.baseName + "-clusterAS", {
        name: autoscalerNS,
        namespace: autoscalerNS,
    });
    clusterAS.node.addDependency(kuberNS);
    clusterAS.role.addManagedPolicy(aws_iam_1.ManagedPolicy.fromAwsManagedPolicyName("AdministratorAccess"));
    eksr.eks.addManifest("CRB-" + eksr.props.baseName + "-clusterAS", {
        apiVersion: "rbac.authorization.k8s.io/v1beta1",
        kind: "ClusterRoleBinding",
        metadata: {
            name: eksr.props.baseName + "-clusterAS",
        },
        roleRef: {
            apiGroup: "rbac.authorization.k8s.io",
            kind: "ClusterRole",
            name: "cluster-admin",
        },
        subjects: [
            {
                kind: "ServiceAccount",
                name: clusterAS.serviceAccountName,
                namespace: clusterAS.serviceAccountNamespace,
            },
        ],
    });
    new aws_eks_1.HelmChart(stack, "HELM-" + eksr.props.baseName + "-autoscaler", {
        cluster: eksr.eks,
        release: "autoscaler",
        namespace: clusterAS.serviceAccountNamespace,
        chart: "cluster-autoscaler-chart",
        repository: "https://kubernetes.github.io/autoscaler",
        version: props.autoscalerVersion || "1.0.1",
        values: {
            awsRegion: stack.region,
            autoDiscovery: {
                clusterName: eksr.eks.clusterName,
            },
            rbac: {
                serviceAccount: {
                    create: false,
                    name: clusterAS.serviceAccountName,
                },
            },
        },
    });
    return onDemandASG;
}
exports.autoscaler = autoscaler;
//# sourceMappingURL=autoscaler.js.map