"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.developerServiceAccount = void 0;
var aws_iam_1 = require("@aws-cdk/aws-iam");
function developerServiceAccount(eksr, props) {
    var developerNS = props.developerNS || "developer";
    var devAdmin = eksr.eks.addServiceAccount("SA-" + eksr.props.baseName + "-" + developerNS + "-developer", {
        name: developerNS,
        namespace: developerNS,
    });
    var nsDeveloper = eksr.eks.addManifest("NS-" + eksr.props.baseName + "-" + developerNS, {
        apiVersion: "v1",
        kind: "Namespace",
        metadata: { name: developerNS },
    });
    devAdmin.node.addDependency(nsDeveloper);
    devAdmin.role.addManagedPolicy(aws_iam_1.ManagedPolicy.fromAwsManagedPolicyName("AdministratorAccess"));
    eksr.eks.addManifest("CRB-" + eksr.props.baseName + "-" + developerNS + "-binding", {
        apiVersion: "rbac.authorization.k8s.io/v1beta1",
        kind: "ClusterRoleBinding",
        metadata: {
            name: developerNS + "-binding",
        },
        roleRef: {
            apiGroup: "rbac.authorization.k8s.io",
            kind: "ClusterRole",
            name: "cluster-admin",
        },
        subjects: [
            {
                kind: "ServiceAccount",
                name: devAdmin.serviceAccountName,
                namespace: devAdmin.serviceAccountNamespace,
            },
        ],
    });
    return devAdmin;
}
exports.developerServiceAccount = developerServiceAccount;
//# sourceMappingURL=developer-service-account.js.map