"use strict";
// import * as path from 'path'
Object.defineProperty(exports, "__esModule", { value: true });
exports.eksStack = void 0;
var iam = require("@aws-cdk/aws-iam");
var ec2 = require("@aws-cdk/aws-ec2");
var eks = require("@aws-cdk/aws-eks");
function eksStack(stack, props) {
    var myVPC;
    if (props.vpcId) {
        myVPC = ec2.Vpc.fromLookup(stack, "VPC-" + props.baseName, { vpcId: props.vpcId });
    }
    else if (props.cidr) {
        myVPC = new ec2.Vpc(stack, "VPC-" + props.baseName, {
            cidr: props.cidr,
        });
    }
    else {
        throw Error("we need a vpcid or cidr");
    }
    var clusterAdmin = new iam.Role(stack, "Role-" + props.baseName + "-clusterAdmin", {
        assumedBy: new iam.AccountRootPrincipal(),
    });
    var eksCluster = new eks.Cluster(stack, "EKS-" + props.baseName, {
        clusterName: "" + props.baseName,
        mastersRole: clusterAdmin,
        vpc: myVPC,
        kubectlEnabled: true,
        defaultCapacity: 0,
        version: props.EKSVersion || eks.KubernetesVersion.V1_17,
    });
    eksCluster.addManifest("SC-" + props.baseName + "-gp2-encrypted", {
        apiVersion: "storage.k8s.io/v1",
        kind: "StorageClass",
        metadata: {
            name: "gp2-encrypted",
        },
        provisioner: "kubernetes.io/aws-ebs",
        parameters: {
            type: "gp2",
            encrypted: "true",
        },
        reclaimPolicy: "Retain",
        allowVolumeExpansion: true,
    });
    return {
        props: props,
        eks: eksCluster
    };
}
exports.eksStack = eksStack;
//# sourceMappingURL=eks-stack.js.map