"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.externalDNS = void 0;
var iam = require("@aws-cdk/aws-iam");
var aws_iam_1 = require("@aws-cdk/aws-iam");
function externalDNS(eksr, props) {
    var toolsNS = props.externalDnsNamespace || 'kuber';
    var dnsAdmin = eksr.eks.addServiceAccount("SA-" + eksr.props.baseName + "-" + toolsNS + "-externaldns", {
        name: toolsNS + "-externaldns",
        namespace: toolsNS,
    });
    dnsAdmin.addToPolicy(new aws_iam_1.PolicyStatement({
        effect: iam.Effect.ALLOW,
        actions: ['route53:ChangeResourceRecordSets'],
        resources: ['arn:aws:route53:::hostedzone/*'],
    }));
    dnsAdmin.addToPolicy(new aws_iam_1.PolicyStatement({
        effect: iam.Effect.ALLOW,
        actions: ['route53:ListHostedZones', 'route53:ListResourceRecordSets'],
        resources: ['*'],
    }));
    eksr.eks
        .addManifest("CBR-" + eksr.props.baseName + "-" + toolsNS + "-viewer", {
        apiVersion: 'rbac.authorization.k8s.io/v1beta1',
        kind: 'ClusterRoleBinding',
        metadata: {
            name: toolsNS + "-externaldns-viewer",
        },
        roleRef: {
            apiGroup: 'rbac.authorization.k8s.io',
            kind: 'ClusterRole',
            name: dnsAdmin.serviceAccountName,
        },
        subjects: [
            {
                kind: 'ServiceAccount',
                name: dnsAdmin.serviceAccountName,
                namespace: dnsAdmin.serviceAccountNamespace,
            },
        ],
    })
        .node.addDependency(dnsAdmin);
    eksr.eks.addManifest("CR-" + eksr.props.baseName + "-" + toolsNS + "-viewer", {
        apiVersion: 'rbac.authorization.k8s.io/v1beta1',
        kind: 'ClusterRole',
        metadata: { name: toolsNS + "-externaldns-viewer" },
        rules: [
            {
                apiGroups: [''],
                resources: ['services', 'endpoints', 'pods'],
                verbs: ['get', 'watch', 'list'],
            },
            {
                apiGroups: ['extensions', 'networking.k8s.io'],
                resources: ['ingresses'],
                verbs: ['get', 'watch', 'list'],
            },
            {
                apiGroups: [''],
                resources: ['nodes'],
                verbs: ['list', 'watch'],
            },
        ],
    });
    var externalDnsImage = props.externalDnsImage || 'registry.opensource.zalan.do/teapot/external-dns:latest';
    eksr.eks
        .addManifest("Deployment-" + eksr.props.baseName + "-" + toolsNS + "-externaldns", {
        apiVersion: 'apps/v1',
        kind: 'Deployment',
        metadata: {
            name: toolsNS + "-externaldns",
            namespace: dnsAdmin.serviceAccountNamespace,
        },
        spec: {
            strategy: { type: 'Recreate' },
            selector: {
                matchLabels: {
                    app: toolsNS + "-externaldns",
                },
            },
            template: {
                metadata: {
                    labels: {
                        app: toolsNS + "-externaldns",
                    },
                },
                spec: {
                    serviceAccount: dnsAdmin.serviceAccountName,
                    containers: props.zones.map(function (zone) { return ({
                        name: "edns-" + zone.zoneName.replace(/\./g, '-'),
                        image: externalDnsImage,
                        args: [
                            '--source=service',
                            '--source=ingress',
                            "--domain-filter=" + zone.zoneName,
                            '--provider=aws',
                            '--policy=upsert-only',
                            '--aws-zone-type=public',
                            '--registry=txt',
                            "--txt-owner-id=" + zone.hostedZoneId,
                        ],
                    }); }),
                    securityContext: {
                        fsGroup: 65534,
                    },
                },
            },
        },
    })
        .node.addDependency(dnsAdmin);
}
exports.externalDNS = externalDNS;
//# sourceMappingURL=external-dns.js.map