"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.githubWorker = void 0;
function githubWorker(eksr, zones, serviceAccount, props) {
    var url = new URL(props.url);
    var workerName = eksr.props.baseName + "-" + url.port.replace(/[\/\.]+/, "-");
    eksr.eks.addManifest("Deployment-" + eksr.props.baseName + "-" + workerName, {
        apiVersion: "apps/v1",
        kind: "Deployment",
        metadata: {
            name: workerName,
            namespace: serviceAccount.serviceAccountNamespace,
            labels: {
                "app.kubernetes.io/name": "github-worker-" + workerName,
            },
        },
        spec: {
            replicas: props.replicaCount || 1,
            strategy: {
                type: "RollingUpdate",
            },
            selector: {
                matchLabels: {
                    "app.kubernetes.io/name": "github-worker-" + workerName,
                    "app.kubernetes.io/instance": "github-worker-" + workerName,
                },
            },
            template: {
                metadata: {
                    annotations: {},
                    labels: {
                        "app.kubernetes.io/name": "github-worker-" + workerName,
                        "app.kubernetes.io/instance": "github-worker-" + workerName,
                    },
                },
                spec: {
                    serviceAccountName: serviceAccount.serviceAccountName,
                    securityContext: {
                        fsGroup: 27,
                    },
                    containers: [
                        {
                            name: "dind",
                            image: "docker:dind",
                            securityContext: {
                                privileged: true,
                            },
                            command: [
                                "/usr/local/bin/dockerd",
                                "--host=unix:///var/run/docker.sock",
                                "--host=tcp://0.0.0.0:2376",
                            ],
                        },
                        {
                            name: "worker",
                            image: props.image,
                            command: props.command || ["/usr/local/bin/worker.sh"],
                            imagePullPolicy: "Always",
                            env: [
                                {
                                    name: "GITHUB_ACCESS_TOKEN",
                                    value: props.token,
                                },
                                {
                                    name: "RUNNER_REPOSITORY_URL",
                                    value: props.url,
                                },
                                {
                                    name: "RUNNER_LABELS",
                                    value: __spreadArrays((props.labels || []), [
                                        eksr.props.baseName
                                    ], zones.map(function (i) { return i.zoneName; })).join(","),
                                },
                                {
                                    name: "DOCKER_HOST",
                                    value: "tcp://127.0.0.1:2376",
                                },
                            ],
                            resources: {},
                            volumeMounts: [],
                        },
                    ],
                    nodeSelector: {},
                    affinity: {},
                    tolerations: [],
                },
            },
        },
    });
}
exports.githubWorker = githubWorker;
//# sourceMappingURL=github-worker.js.map